summaryrefslogtreecommitdiffstats
path: root/ksplashml/themeengine/standard/wndstatus.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 20:16:47 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 20:16:47 +0000
commit495d08bc2db58ee7fc4ea55a7158f2f61b82fc56 (patch)
treedaabcb652c07b9a17cad88ca50b63a2d91ead4a3 /ksplashml/themeengine/standard/wndstatus.cpp
parent50001f1757f97510e80cb1990e2f2d5b00144c2a (diff)
downloadtdebase-495d08bc2db58ee7fc4ea55a7158f2f61b82fc56.tar.gz
tdebase-495d08bc2db58ee7fc4ea55a7158f2f61b82fc56.zip
Automated conversion for enhanced compatibility with TQt for Qt4 3.4.0 TP1
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdebase@1211357 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'ksplashml/themeengine/standard/wndstatus.cpp')
-rw-r--r--ksplashml/themeengine/standard/wndstatus.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/ksplashml/themeengine/standard/wndstatus.cpp b/ksplashml/themeengine/standard/wndstatus.cpp
index 04685d9cf..f8bc3d964 100644
--- a/ksplashml/themeengine/standard/wndstatus.cpp
+++ b/ksplashml/themeengine/standard/wndstatus.cpp
@@ -27,17 +27,17 @@
#include "wndstatus.h"
#include "wndstatus.moc"
// WndStatus::WndStatus(): Display a nifty status bar at
// the bottom of the screen, so the user always knows what's
// happening to his system.
-WndStatus::WndStatus( TQPalette /*pal*/,
+WndtqStatus::WndtqStatus( TQPalette /*pal*/,
int xineramaScreen,
bool atTop, bool pbVisible,
const TQFont& font,
const TQColor& fgc, const TQColor & bgc,
const TQString& icon
)
- :TQHBox( 0, "wndStatus", WStyle_Customize|WX11BypassWM )
+ :TQHBox( 0, "wndtqStatus", WStyle_Customize|WX11BypassWM )
{
setFrameStyle( TQFrame::NoFrame );
//setPalette( pal );
@@ -83,19 +83,19 @@ WndStatus::WndStatus( TQPalette /*pal*/,
m_progress->hide();
}
-void WndStatus::slotSetMessage( const TQString& msg )
+void WndtqStatus::slotSetMessage( const TQString& msg )
{
raise();
m_label->setText( msg );
}
-void WndStatus::slotUpdateProgress( int i )
+void WndtqStatus::slotUpdateProgress( int i )
{
raise();
m_progress->setProgress( i );
}
-void WndStatus::slotUpdateSteps( int i )
+void WndtqStatus::slotUpdateSteps( int i )
{
m_progress->setTotalSteps( i );
}
@@ -27,17 +27,17 @@
#include "wndstatus.h"
#include "wndstatus.moc"
-// WndStatus::WndStatus(): Display a nifty status bar at
+// WndtqStatus::WndtqStatus(): Display a nifty status bar at
// the bottom of the screen, so the user always knows what's
// happening to his system.